@@ -15,15 +15,15 @@ r.url('https://ca.yahoo.com')
 
 # use type() to enter text into an UI element or x, y location
 # '[enter]' = enter key, '[clear]' = clear field
-r.type('search-input', 'github')
+r.type('ybar-sbq', 'github')
 
 # use read() to fetch and return text from UI element
-search_text = r.read('search-input')
+search_text = r.read('ybar-sbq')
 print(search_text)
 
 # use click() to click on an UI element or x, y location
 # rclick() = right-click, dclick() = double-click
-r.click('search-button')
+r.click('ybar-search')
 
 # use wait() to wait for a number of seconds
 # default wait() is 5 seconds
